summaryrefslogtreecommitdiffstats
path: root/usr.bin/window/wwspawn.c
diff options
context:
space:
mode:
Diffstat (limited to 'usr.bin/window/wwspawn.c')
-rw-r--r--usr.bin/window/wwspawn.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/usr.bin/window/wwspawn.c b/usr.bin/window/wwspawn.c
index 57e2f66..3588dd8 100644
--- a/usr.bin/window/wwspawn.c
+++ b/usr.bin/window/wwspawn.c
@@ -42,7 +42,7 @@ static char sccsid[] = "@(#)wwspawn.c 8.1 (Berkeley) 6/6/93";
#include <signal.h>
/*
* There is a dead lock with vfork and closing of pseudo-ports.
* So we have to be sneaky about error reporting.
*/
wwspawn(wp, file, argv)
@@ -56,7 +56,7 @@ char **argv;
int s;
s = sigblock(sigmask(SIGCHLD));
- switch (pid = vfork()) {
+ switch (pid = fork()) {
case -1:
wwerrno = WWE_SYS;
ret = -1;
@@ -42,7 +42,7 @@ static char sccsid[] = "@(#)wwspawn.c 8.1 (Berkeley) 6/6/93";
#include <signal.h>
/*
- * There is a dead lock with vfork and closing of pseudo-ports.
+ * There is a dead lock with fork and closing of pseudo-ports.
* So we have to be sneaky about error reporting.
*/
OpenPOWER on IntegriCloud